local mod = ...




-- Create: Job, Quest, Event -------------------------------------------------------------------------------------
function SecurityRegisterTheft(resource)

    -- Job: Event Trigger -------------------------------------------------------------------------------------
    mod:register({
        DataType = "JOB",
        Id = "JOB_SECURITY_EVENT_THEFT_" .. resource,
        JobName = "EVENT_SECURITY_THEFT_NAME",
        JobDescription = "EVENT_SECURITY_THEFT_NAME",
        IsLockedByDefault = true,
        Hidden = true,
        DefaultBehavior = "BEHAVIOR_WORK",
        ProductionDelay = 0.0, -- default 30
        AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
        CharacterSetup = {
            DataType = "CHARACTER_SETUP",
            IdleAnimation = "IDLE"
        }
    })

    mod:override({ Id = "NEWCOMER", CompatibleJobList = { Action = "APPEND", "JOB_SECURITY_EVENT_THEFT_" .. resource } })
    mod:override({ Id = "SERF", CompatibleJobList = { Action = "APPEND", "JOB_SECURITY_EVENT_THEFT_" .. resource } })
    mod:override({ Id = "COMMONER", CompatibleJobList = { Action = "APPEND", "JOB_SECURITY_EVENT_THEFT_" .. resource } })
    mod:override({ Id = "CITIZEN", CompatibleJobList = { Action = "APPEND", "JOB_SECURITY_EVENT_THEFT_" .. resource } })


    -- Quest ---------------------------------------------------------------------------------------------
    mod:register({
        DataType = "QUEST",
        Id = "QUEST_SECURITY_EVENT_THEFT_" .. resource,
        Name = "EVENT_SECURITY_THEFT_NAME",
        Description = "EVENT_SECURITY_THEFT_NAME",
        IsSilent = true,
        QuestFunction = {
            DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
            Job = "JOB_SECURITY_EVENT_THEFT_" .. resource
        },
        QuestRewardList = nil,
        QuestFailList = nil,
        QuestListToUnlockAfter = nil,
        OnFailCallback = nil,
        OnSuccessCallback = {
            DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
            Event = "EVENT_SECURITY_EVENT_THEFT_" .. resource
        }
    })


    -- Default Balancing (event list) ---------------------------------------------------------------------------------------------
    mod:override({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND", 
            "EVENT_SECURITY_EVENT_SETUP_THEFT_" .. resource,
        },
    })


    -- Event: Setup Theft ---------------------------------------------------------------------------------------------
    mod:register({
        DataType = "EVENT",
        Id = "EVENT_SECURITY_EVENT_SETUP_THEFT_" .. resource,
        Title = "EVENT_SECURITY_THEFT_NAME",
        Description = "EVENT_SECURITY_THEFT_NAME",
        IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
        IsRecurrent = false,
        DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
        ConditionList = {
            {
                DataType = "EVENT_CONDITION_BUILDING_BUILT",
                AssetBuilding = "BUILDING_VILLAGE_CENTER"
            }
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = "QUEST_SECURITY_EVENT_THEFT_" .. resource
            },
        }
    })


    -- Event: Theft ---------------------------------------------------------------------------------------------------------------
    mod:register({
        DataType = "EVENT",
        Id = "EVENT_SECURITY_EVENT_THEFT_" .. resource,
        Title = "EVENT_SECURITY_THEFT_NAME",
        Description = "EVENT_SECURITY_THEFT_NAME",
        IsInMainPool = false,
        IsRecurrent = true,
        DaysToFirst = 1,
        ConditionList = {
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_PAY",
                AmountToPay = {
                    {
                        Resource = resource,
                        Quantity = math.random(30, 50),
                    },
                },
            },
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = "QUEST_SECURITY_EVENT_THEFT_" .. resource
            },
        }
    })

end



SecurityRegisterTheft("GOLD_COINS")
SecurityRegisterTheft("BREAD")
SecurityRegisterTheft("TOOL")
SecurityRegisterTheft("BEER")
SecurityRegisterTheft("CHEESE")
SecurityRegisterTheft("COAL")
SecurityRegisterTheft("BARREL")
SecurityRegisterTheft("MILK")
SecurityRegisterTheft("FISH")
SecurityRegisterTheft("BERRIES")
SecurityRegisterTheft("GLASS")
SecurityRegisterTheft("GOLD_BARS")
SecurityRegisterTheft("HOP")
SecurityRegisterTheft("BOAR")
SecurityRegisterTheft("IRON")
SecurityRegisterTheft("JEWELRY")
SecurityRegisterTheft("PLANK")
SecurityRegisterTheft("STONE")
SecurityRegisterTheft("POLISHED_STONE")
SecurityRegisterTheft("CLOTHES")
SecurityRegisterTheft("WOOL")
SecurityRegisterTheft("GRAPES")
SecurityRegisterTheft("SWORD")
SecurityRegisterTheft("WOOLEN_CLOTH")
SecurityRegisterTheft("WHEAT")
SecurityRegisterTheft("FLOUR")
SecurityRegisterTheft("WOOD")

